pub struct EventRow {
room_history: WeakRef<RoomHistory>,
message_toolbar_handler: RefCell<Option<SignalHandlerId>>,
composer_state: BoundObjectWeakRef<ComposerState>,
event: BoundObject<Event>,
action_group: RefCell<Option<SimpleActionGroup>>,
shortcut_controller: RefCell<Option<ShortcutController>>,
permissions_handler: RefCell<Option<SignalHandlerId>>,
target_user_handler: RefCell<Option<SignalHandlerId>>,
}Fields
room_history: WeakRef<RoomHistory>The ancestor room history of this row.
message_toolbar_handler: RefCell<Option<SignalHandlerId>>composer_state: BoundObjectWeakRef<ComposerState>event: BoundObject<Event>The event presented by this row.
action_group: RefCell<Option<SimpleActionGroup>>The event action group of this row.
shortcut_controller: RefCell<Option<ShortcutController>>permissions_handler: RefCell<Option<SignalHandlerId>>target_user_handler: RefCell<Option<SignalHandlerId>>Implementations
Sourceimpl EventRow
impl EventRow
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl EventRow
impl EventRow
Sourcefn set_room_history(&self, room_history: &RoomHistory)
fn set_room_history(&self, room_history: &RoomHistory)
Set the ancestor room history of this row.
Watch the related event for given current composer state of the toolbar.
Sourcefn disconnect_event_signals(&self)
fn disconnect_event_signals(&self)
Disconnect the signal handlers.
Sourcefn build_event_widget(&self, event: Event)
fn build_event_widget(&self, event: Event)
Construct the widget for the given event
Sourcefn update_highlight(&self)
fn update_highlight(&self)
Update the highlight state of this row.
Update this row for the related event with the given identifier.
Sourcefn update_actions(&self)
fn update_actions(&self)
Update the actions available for the given event.